@@ -24,9 +24,6 @@
       record /ptcl/ tgspec(209), pjspec(209)
       integer:: ntgspec, npjspec, nout
       real(8):: impactp 
-c//////////////// to see ela/inela ratio
-!      real(8):: sumTE
-c////////////////////
 
 c/////////
       integer:: i
@@ -39,7 +36,8 @@ c//////////
          write(0,*) 'in cjamEvent: strange target A,Z',ia,iz
          stop
       endif
-!        if 0 K.E, only elastic events are obtained-->loop
+!        if anti-p has  0 K.E, 
+!        only elastic events are obtained; avoid loop
       if(  pj.code== knuc .and. pj.charge==-1
      *     .and.  pj.fm.p(4) - pj.mass <=0.0 ) then
          pj.fm.p(4) = 0.001d0 + pj.mass
@@ -114,7 +112,7 @@ c///////////////
                write(0,*) 'pj=',pj.code, pj.subcode,pj.charge
                write(0,*) 'pj KE=',pj.fm.p(4)- pj.mass
                write(0,*) 'tg A,Z=', ia,iz
-               write(0,*)' generate # of ptcls =',ntp2
+               write(0,*)' generated # of ptcls =',ntp2
                write(0,*) 'event is neglected'
                ntp = 0
                exit
@@ -125,9 +123,6 @@ c///////////////
 !                                JamXs=0-->ok= t. but 
 !                           cjamPjSpec dose not generate any frgment
 !                           so don't worry)
-c/////////////
-
-
 #if defined ShowFragment 
          write(0,'(a,3i4,a,1p,g12.3,a, l)')
      *        'pj=', pj.code, pj.subcode, pj.charge,
@@ -142,11 +137,11 @@ c/////////////
      *         a(i).fm.p(4) - a(i).mass
          enddo
 #endif
-c//////////////
+
          if(ok) then
             if(npjspec > 0 ) then
-               call cjamPjSpec(pj, ia, iz,
-     *         pjspec, npjspec, impactp, inela, a(ntp2+1), nout)
+               call cjamPjSpec(pj, tg,
+     *            pjspec, npjspec, impactp, inela, a(ntp2+1), nout)
             else
                nout = 0
             endif
@@ -163,7 +158,7 @@ c/////////
 c/////////// 
             ntp2 = ntp2 + nout
             if(ntgspec > 0 ) then
-               call cjamTgSpec(pj, ia, iz,
+               call cjamTgSpec(pj, tg,
      *           tgspec, ntgspec, impactp, inela, a(ntp2+1), nout)
             else
                nout = 0
@@ -242,17 +237,16 @@ c//////////////
          ntp = ntp + 1
          a(ntp) =  a(i)
       enddo
-      
       if( abs( sumTE/(pj.fm.p(4) + tg.mass) - 1.0d0) > eps ) then
          if( pj.code == kgnuc ) then
             projA = pj.subcode
          else
             projA= 1.
          endif
-         write(0,'(a, 4i4, 1p,2g12.4)')
-     *    'E consv err;retry', tg.code, tg.subcode, pj.code, pj.subcode,
-     *            (pj.fm.p(4)-pj.mass)/projA,
-     *    sumTE/(pj.fm.p(4) + tg.mass) - 1.0d0
+!         write(0,'(a, 4i4, 1p,2g12.4)')
+!     *    'E consv err;retry', tg.code, tg.subcode, pj.code, pj.subcode,
+!     *            (pj.fm.p(4)-pj.mass)/projA,
+!     *    sumTE/(pj.fm.p(4) + tg.mass) - 1.0d0
          ok = .false.
       else
          ok = .true.
@@ -287,9 +281,6 @@ c      implicit double (...)
       save
       
       if(first .eq. 1) then
-c//////////:  this call may unresolved ref. for utilities in Epics
-c         call mydummy
-c////////
          first = 0
          mevent = 1
          bmin = 0.
@@ -324,12 +315,6 @@ c	targ = '2:1'
       else
          write(cwin, '(f12.3,"gev")')  (pj.fm.p(4)-pj.mass)
       endif
-c      call kseblk(cwin, "*", nc)
-c      cwin = '14.6gevc'
-c///////////
-c      write(0,*) ' jaminit bmax=',bmax, ' sig=',sig, ' targ=',targ,
-c     *   'proj=',proj
-c//////////////
       call jaminit(mevent, bmin, bmax, dt, nstep, frame, proj, targ,
      *  cwin)
       end
@@ -424,17 +409,6 @@ c      implicit double (...)
       record /ptcl/ aptcl
       integer::nn, hn, rn  ! # of free N, Heavy ions and Remnant
       save
-c///////////
-cc            these are to see the collsion of incident
-cc            particles only
-c      record /ptcl/ inci
-c      integer,save::first=0
-c      real*8  tgTE, pjTE
-c      if( first == 0 ) then
-c         inci = pj
-c         first = 1
-c      endif
-c///////////
       pprobt = iz
       pprobt = pprobt/ia   !  rough proton probabilty of target spectator
       if( pj.code == kgnuc ) then
@@ -562,16 +536,14 @@ c      endif
 c/////////////////
       impactp = pard(2) ! is in jam2.inc
       end
-      subroutine  cjamPjSpec(pj, iat, izt,
+      subroutine  cjamPjSpec(pj, tg,
      *            pjspec, npjspec, impactp, inela, a, nout)
       use modTargetFrag
-      use modfragment
       implicit none
 #include "Zptcl.h"
 #include "Zcode.h"
       record /ptcl/ pj ! input. proj.
-      integer,intent(in)::iat  !  target A
-      integer,intent(in)::izt  !  target Z
+      record /ptcl/ tg ! //     taget
       record /ptcl/pjspec(*) !input. projectile spector
       integer,intent(in):: npjspec ! # of ptcls in pjspec
       real(8),intent(in):: impactp ! impact parameter in fm of the interaction
@@ -579,6 +551,8 @@ c/////////////////
       record /ptcl/a(*)  ! output.  fragment from the spectator
       integer,intent(out):: nout ! # of ptcls in a
 
+      integer::iat, izt  !  target A, Z
+
       integer:: pjA, pjZ 
       integer:: nw  ! woonded N
       integer:: oA(209),  oZ(209)
@@ -591,91 +565,140 @@ c/////////////////
       break = .true.
       nout = 0
       n = 0
+      if(tg.code == kgnuc) then
+         iat = tg.subcode
+      else
+         iat = 1
+      endif
+      izt = tg.charge
       if( inela == 0 .and. pj.code /= kgnuc ) then  !  elastic event. proj. is only 1  spectator
          nout = nout + 1
          a(nout) = pjspec(1)
-         break=.false.
       elseif( iat == 1) then  ! fragm cannot treat this case
          break=.false.
       elseif( npjspec > 0 ) then  
-         nw = pj.subcode - npjspec
          pjA = pj.subcode
-         if( pjA <= 56 ) then
-            call fragm(iat, pjA, nw, impactp, nout, oA, oZ)
-            !       nout: # of fragment
-            !       oA(i): i-th fragment A (i=1,nout)
-            do i = 1, nout
-               if( oA(i) == 1 ) then
-                  n = n + 1              ! n/p
-                  a(i) =  pjspec(n)
-                  a(i).charge =  oZ(i)
-               else
-                  a(i).fm.p(1:4) = 0.   
-                  do j = 1, oA(i)
-                     n = n + 1
-                     a(i).fm.p(1:4) = a(i).fm.p(1:4)
-     *                                + pjspec(n).fm.p(1:4)
-                  enddo
-                  call cmkptc(kgnuc, oA(i), oZ(i), a(i) )
-                  call cmkptc(kgnuc, oA(i), 1, a(i))
-                  a(i).mass = sqrt( a(i).fm.p(4)**2 
-     *               -   dot_product(a(i).fm.p(1:3), a(i).fm.p(1:3)) )
-                  if(oA(i) == 2) then   ! d
-                     a(i).charge = 1
-                  elseif( oA(i) <= 4 ) then  ! He3 or He4
-                     a(i).charge = 2
-                  elseif( oA(i) < 20 ) then
-                     a(i).charge = max(3.0, oA(i)*0.5)
-                  else
-                     a(i).charge = oA(i)*0.4
-                  endif
-               endif
-            enddo
-         else  !  proj>56. use cTargetFrag. by exchanging proj and target (so the target
-               ! must be A<=56)
-            if(iat <= 56 ) then
-                  !  iat, izt -- > proj
-               pjZ= pj.charge  ! pjA, pjZ --> target
-               call cSampFragNHR(iat, izt,  pjA, pjZ, npjspec, 
-     *               nn, hn, rn, oA, oZ)
-               nout =  nn+hn+rn
-               do i = 1, nout
-                  if( oA(i) == 1 ) then
-                     n = n + 1  ! n/p
-                     a(i) =  pjspec(n)
-                     a(i).charge = oZ(i)
-                  else
-                     a(i).fm.p(1:4) = 0.   
-                     do j = 1, oA(i)
-                        n = n + 1
-                        a(i).fm.p(1:4) = a(i).fm.p(1:4)
-     *                                + pjspec(n).fm.p(1:4)
-                     enddo
-                     call cmkptc(kgnuc, oA(i), oZ(i), a(i))
-                     a(i).mass = sqrt( a(i).fm.p(4)**2 
-     *                -   dot_product(a(i).fm.p(1:3), a(i).fm.p(1:3)) )
-                  endif
-               enddo
-            else
-               if( nwrong < 20 ) then
-                  nwrong = nwrong + 1
-                  write(0,*)
-     *             '!!!!!!!!!!!!!!! warning from cjamPjSpec #', nwrong
-                  write(0,*) ' Too large A of proj./ target'
-                  write(0,*) '  pj A, tg A=',pjA, iat
-                  write(0,*) 'All spectators are treated as 1 nucleus'
-               endif
-               break = .false.
-            endif
-         endif
+         if( pjA  > 56 .and. iat > 56) then
+            call csampNucFrag(pj, iat, izt, npjspec,
+     *             a, nout)
+         elseif(pjA > 56 ) then  ! iat<=56
+            !        use NHR by exchaning pj and target
+            call cuseFragNHR(iat, izt,  pjA, pjZ, pjspec,  npjspec,
+     *            oA, oZ, a, nout)
+         else
+            nw = pj.subcode - npjspec
+            !    use fragm (target comes 1st)
+            call cusefragm(iat, pjA, nw, pjspec,
+     *           impactp, oA, oZ,   a, nout)
+         endif  
       endif
       if( .not. break ) then
+!              spectator nucleons do not breakup. so 
+!              make them an ion
          if( npjspec > 0 ) then 
             nout = nout + 1
             call cjamNoFrag(pj, npjspec, pjspec, a(nout))
          endif
       endif
       end
+      
+      subroutine cuseFragNHR(pjA, pjZ, iat, izt, tgspec,  ntgspec, 
+     *            oA, oZ, a, nout)
+      use modTargetFrag
+!           this is to sample fragmentation particles from
+!           target.  target  A must be  >= 56.  proj A <=56
+      implicit none
+#include "Zptcl.h"
+#include "Zcode.h"
+      integer,intent(in):: pjA, pjZ  ! projectil A,Z  A<=56
+      integer,intent(in)::iat, izt  !  target A,Z  A>=56
+      record /ptcl/tgspec(*)  ! input.  spectator nucleon info.
+      integer,intent(in):: ntgspec ! # of target spectator in tgspec
+      integer,intent(out):: oA(209),  oZ(209) ! working array
+      record /ptcl/a(*)  ! output.  fragment from the target
+      integer,intent(out):: nout ! # of ptcls in a
+
+
+      integer:: i, j, n
+      integer:: nn, hn, rn
+
+      call cSampFragNHR(pjA, pjZ, iat, izt,  ntgspec,
+     *     nn, hn, rn, oA, oZ)
+      n = 0
+      nout =  nn+hn+rn
+      do i = 1, nout
+         if( oA(i) == 1 ) then
+            n = n + 1           ! n/p
+            a(i) =  tgspec(n)
+            a(i).charge = oZ(i)
+         else
+            a(i).fm.p(1:4) = 0.   
+            do j = 1, oA(i)
+               n = n + 1
+               a(i).fm.p(1:4) = a(i).fm.p(1:4)
+     *              + tgspec(n).fm.p(1:4)
+            enddo
+            call cmkptc(kgnuc, oA(i), oZ(i), a(i))
+            a(i).mass = sqrt( a(i).fm.p(4)**2 
+     *           -   dot_product(a(i).fm.p(1:3), a(i).fm.p(1:3)) )
+         endif
+      enddo
+      end subroutine cusefragNHR
+
+      subroutine cusefragm(iat, pjA, nw, pjspec, 
+     *   impactp, oA, oZ, a, nout)
+      use modfragment, only: fragm
+!            this is to call fragm routine
+      implicit none
+#include "Zptcl.h"
+#include "Zcode.h"
+      integer,intent(in):: iat  !  target A
+      integer,intent(in):: pjA ! projectile A
+      integer,intent(in):: nw  ! woonded N
+      record /ptcl/pjspec(*)  ! input projectile spectator info
+      real(8),intent(in):: impactp ! impact parameter in fm of the interaction
+      integer,intent(out):: oA(209),  oZ(209)
+             !  this is used inside of this prog. 
+      integer,intent(out):: nout ! # of fragment in oA, oZ and a 
+      record /ptcl/ a(*)  ! output.  fragment from the spectator
+
+
+      integer:: i, j,  n
+      n = 0
+!              target comes first 
+      call fragm(iat, pjA, nw, impactp, nout, oA, oZ)
+      do i = 1, nout
+         if( oA(i) == 1 ) then
+            n = n + 1           ! n/p
+            a(i) =  pjspec(n)
+            if( oZ(i) > 1 ) then
+               oZ(i) = 1  ! never seen, but for safety.  
+            endif
+            a(i).charge =  oZ(i)
+         else
+            a(i).fm.p(1:4) = 0.   
+            do j = 1, oA(i)
+               n = n + 1
+               a(i).fm.p(1:4) = a(i).fm.p(1:4)
+     *              + pjspec(n).fm.p(1:4)
+            enddo
+            call cmkptc(kgnuc, oA(i), oZ(i), a(i) )
+!!            call cmkptc(kgnuc, oA(i), 1, a(i))
+            a(i).mass = sqrt( a(i).fm.p(4)**2 
+     *           -   dot_product(a(i).fm.p(1:3), a(i).fm.p(1:3)) )
+            if(oA(i) == 2) then ! d
+               a(i).charge = 1
+            elseif( oA(i) <= 4 ) then ! He3 or He4
+               a(i).charge = 2
+            elseif( oA(i) < 20 ) then
+               a(i).charge = max(3.0, oA(i)*0.5)
+            else
+               a(i).charge = oA(i)*0.4
+            endif
+         endif
+      enddo
+      end subroutine cusefragm
+
       subroutine cjamNoFrag(p0, nspec, spec,  a)
       implicit none
 #include "Zptcl.h"
@@ -696,6 +719,18 @@ c/////////////////
          enddo
          a.subcode = nspec
          a.code = kgnuc
+         if( a.charge <= 0 ) then 
+!               very very rare; happend when target is H
+!              and pj is He.  
+!            write(0,*) 'In cjamNoFrag.  p0=',p0.fm.p(1:4) 
+!            write(0,*) 'nspec =', nspec
+!            write(0,*) ' charge sum=',0
+!        if Z=0 is kept, dpmjet will die by NEGATIVE ENERGY.
+            a.charge = 1
+!              next is for safety
+         elseif( a.charge >= nspec  .and. nspec > 1 ) then
+            a.charge = max(nspec/2, 1)
+         endif
          a.mass =  a.fm.p(4)**2 -
      *    dot_product(a.fm.p(1:3), a.fm.p(1:3))
 !         if(a.mass < 0. ) then
@@ -707,16 +742,14 @@ c/////////////////
       endif
       end 
 
-      subroutine cjamTgSpec(pj, iat, izt,
+      subroutine cjamTgSpec(pj, tg,
      *            tgspec, ntgspec, impactp, inela, a, nout)
-      use modfragment
       use modTargetFrag
       implicit none
 #include "Zptcl.h"
 #include "Zcode.h"
       record /ptcl/ pj ! input. proj.
-      integer,intent(in)::iat  !  target A
-      integer,intent(in)::izt  !  target Z
+      record /ptcl/ tg ! input. target.
       record /ptcl/tgspec(*) !input. target spectator
       integer,intent(in):: ntgspec ! # of ptcls in tgspec
       real(8):: impactp  ! impact parameter in fm
@@ -724,6 +757,8 @@ c/////////////////
       record /ptcl/a(*)  ! output.  fragment from the spectator
       integer,intent(out):: nout ! # of ptcls in a
 
+      integer::iat, izt  !  target A,Z
+
       integer:: pjA, pjZ 
       integer:: oA(209),  oZ(209)
       integer:: nw  ! # of woonded target nucleons
@@ -733,7 +768,18 @@ c/////////////////
 !       if target A>56 use cSampFragNHR by using proj and targ as they are
       integer,save:: nwrong=0
       logical:: break
-      record /ptcl/ tg
+      if( tg.code == kgnuc) then
+         iat = tg.subcode
+      else
+         iat = 1
+      endif
+      izt = tg.charge
+      if(pj.code == kgnuc ) then
+         pjA = pj.subcode
+      else
+         pjA=1
+      endif
+      pjZ = pj.charge
 
       break = .true.
       nout = 0
@@ -741,100 +787,30 @@ c/////////////////
       if( inela == 0 .and. iat == 1 .and. ntgspec > 0  ) then  ! p/n target and elastic
          nout = nout + 1                      !   inela == 0 is redunant
          a(nout) = tgspec(1)
-         return
-      endif
-
-
-      if( iat > 1  .and. ntgspec > 0 ) then
-         if( pj.code == kgnuc ) then
-            pjA = pj.subcode
-         else
-            pjA = 1
-         endif
-         nw = iat - ntgspec
-         if(pjA == 1 ) then  !  fragm cannot treat this case
-            break = .false.
-         elseif( iat <= 56 ) then ! interchange proj and target
-                       ! target proj. 
-            call fragm(pjA,     iat,  nw, impactp, nout, oA, oZ)
-            !       nout: # of fragment
-            !       oA(i): i-th fragment A (i=1,nout)
-            do i = 1, nout
-               if( oA(i) == 1 ) then
-                  n = n + 1              ! n/p
-                  a(i) =  tgspec(n)
-                  a(i).charge  =  oZ(i)
-               else
-                  a(i).fm.p(1:4) = 0.   
-                  do j = 1, oA(i)
-                     n = n + 1
-                     a(i).fm.p(1:4) = a(i).fm.p(1:4)
-     *                                + tgspec(n).fm.p(1:4)
-                  enddo
-                  call cmkptc(kgnuc, oA(i), oZ(i), a(i))
-                  a(i).mass = sqrt( a(i).fm.p(4)**2 
-     *                 -   dot_product(a(i).fm.p(1:3), a(i).fm.p(1:3)) )
-               endif
-            enddo
-         elseif(pjA<=56) then   !  iat>56. use cTargetFrag. 
-            pjZ= pj.charge  
-            call cSampFragNHR(pjA, pjZ, iat, izt,  ntgspec, 
-     *           nn, hn, rn, oA, oZ)
-            nout =  nn+hn+rn
-            do i = 1, nout
-               if( oA(i) == 1 ) then
-                  n = n + 1     ! n/p
-                  a(i) =  tgspec(n)
-                  a(i).charge = oZ(i)
-               else
-                  a(i).fm.p(1:4) = 0.   
-                  do j = 1, oA(i)
-                     n = n + 1
-                     a(i).fm.p(1:4) = a(i).fm.p(1:4)
-     *                    + tgspec(n).fm.p(1:4)
-                  enddo
-                  call cmkptc(kgnuc, oA(i), oZ(i), a(i))
-                  a(i).mass = sqrt( a(i).fm.p(4)**2 
-     *                 -   dot_product(a(i).fm.p(1:3), a(i).fm.p(1:3)) )
-               endif
-            enddo
-         else
-            if( nwrong < 20 ) then
-               nwrong = nwrong + 1
-               write(0,*)
-     *           '!!!!!!!!!!!!!!! warning from cjamTgSpec #', nwrong
-               write(0,*) ' Too large A of proj./ target'
-               write(0,*) ' pj A, tg Ap=',pjA, iat
-               write(0,*) 'All spectators are treated as 1 nucleus'
+      elseif( ntgspec > 0 ) then  
+         if( iat > 56 .and. pj.subcode > 56) then
+            call csampNucFrag(tg, int(pj.subcode),
+     *           int(pj.charge), ntgspec, a, nout)
+         elseif( iat > 56 ) then !  pjA <=56
+            call cuseFragNHR(pjA, pjZ, iat, izt, tgspec,  ntgspec,
+     *            oA, oZ, a, nout)            
+         elseif(  iat > 1  ) then
+            nw = iat - ntgspec
+            if(pjA == 1 ) then  !  fragm cannot treat this case
+               break = .false.
+            else
+!                     target (=pjA) comes first
+               call cusefragm(pjA, iat, nw, tgspec,
+     *           impactp,  oA, oZ,   a, nout)
             endif
+         else
             break = .false.
          endif
-      else
-         break = .false.
-      endif
-      if(.not. break ) then
-         if( ntgspec > 1 ) then 
-            tg.fm.p(1:4) = 0.
-            tg.charge = 0
-            do i = 1, ntgspec
-               tg.fm.p(1:4) = tg.fm.p(1:4) + tgspec(i).fm.p(1:4) 
-               tg.charge = tg.charge + tgspec(i).charge
-            enddo
-            tg.code = kgnuc
-            tg.subcode = ntgspec
-            tg.mass =( tg.fm.p(4)**2 -
-     *        dot_product(tg.fm.p(1:3), tg.fm.p(1:3) ) )
-
-!            if(tg.mass < 0 ) then
-!               write(0,*) 'err  mass**2 < ', tg.mass
-!            endif
-
-            tg.mass = sqrt(tg.mass)
-            nout = nout + 1
-            a(nout) = tg
-         else
-            nout = nout + 1
-            a(nout) = tgspec(1)
+         if(.not. break ) then
+            if( ntgspec > 1 ) then 
+               nout = nout + 1
+               call cjamNoFrag(tg, ntgspec, tgspec, a(nout))
+            endif
          endif
       endif
       end
