@@ -96,10 +96,13 @@ c
 c        if(IntModel .eq. 'int2' .and.
 c     *      ( pj.code .eq. ktriton .or. pj.code .eq. kdeut) ) then
 
-        if( ActiveMdl .eq. 'dpmjet3' .and.
-     *    (pj.fm.p(4) - pj.mass)/pj.subcode .gt. 5.1) then
-              !   avoid recursive call from cdpmjet
-           call cdpmjet(pj, ia, iz, a, ntp)
+        if( ActiveMdl .eq. 'dpmjet3') then
+           if((pj.fm.p(4) - pj.mass)/pj.subcode .gt. 5.1) then
+              call cdpmjet(pj, ia, iz, a, ntp)
+           else
+!               rescue
+              call cjamEvent(pj, ia, iz, TargetXs, a, ntp)
+           endif
         elseif( ActiveMdl .eq. 'jam') then
            call cjamEvent(pj, ia, iz, TargetXs, a, ntp)
         elseif( ActiveMdl .eq. 'phits') then
@@ -117,34 +120,36 @@ c                  Gheisha should be called directly
            noOfNuc = 0
            noOfInteNuc = 0
         else
-           call csampFragments(pj, ia, frga, noOfFragments,
-     *       nuc, noOfNuc, noOfInteNuc)
-           if(SkipPtclGen .eq. 0) then
-c                 interaction of interating nuc.
-              do  i = 1, noOfInteNuc
-                 j=i + noOfNuc - noOfInteNuc
-                 call chAcol(nuc(j), ia, iz, a(ntp+1), n)
-                 ntp=ntp+n
-              enddo
-c               all business so far is done in the frame where
-c               z axis is the incident
-c               make rotation
-              call crot3mom( pj, a, ntp )
-           endif
-           call crot3mom( pj, nuc, noOfNuc) ! for all nucleons. see entry below
-
-           call crot3mom( pj, frga, noOfFragments)
-
-
-c               move non-interacting nucleon and fragments
-           do  i = 1, noOfNuc - noOfInteNuc 
-              a(ntp+1) = nuc(i)
-              ntp = ntp +1
-           enddo
-           do  i = 1, noOfFragments
-              a(ntp + 1) = frga(i)
-              ntp = ntp + 1
-           enddo
+!              resque
+           call cjamEvent(pj, ia, iz, TargetXs, a, ntp)           
+!!           call csampFragments(pj, ia, frga, noOfFragments,
+!!     *       nuc, noOfNuc, noOfInteNuc)
+!!           if(SkipPtclGen .eq. 0) then
+!!c                 interaction of interating nuc.
+!!              do  i = 1, noOfInteNuc
+!!                 j=i + noOfNuc - noOfInteNuc
+!!                 call chAcol(nuc(j), ia, iz, a(ntp+1), n)
+!!                 ntp=ntp+n
+!!              enddo
+!!c               all business so far is done in the frame where
+!!c               z axis is the incident
+!!c               make rotation
+!!              call crot3mom( pj, a, ntp )
+!!           endif
+!!           call crot3mom( pj, nuc, noOfNuc) ! for all nucleons. see entry below
+!!
+!!           call crot3mom( pj, frga, noOfFragments)
+!!
+!!
+!!c               move non-interacting nucleon and fragments
+!!           do  i = 1, noOfNuc - noOfInteNuc 
+!!              a(ntp+1) = nuc(i)
+!!              ntp = ntp +1
+!!           enddo
+!!           do  i = 1, noOfFragments
+!!              a(ntp + 1) = frga(i)
+!!              ntp = ntp + 1
+!!           enddo
         endif
         return
 c     ****************** inquire the fragments at heavy interation
@@ -239,7 +244,6 @@ c
          noOfInteNuc = 0
          return   !   ********
       endif
-
 c
 c         get heavy group index from the incident charge  
       ihg=Charge2heavyG(pj.charge)
