@@ -371,6 +371,7 @@ c            (icon = 2 means rejection after 20 trials due to wight problem)
 c      ************************************************************
 c         neutral  meson collision.
        subroutine cfakeGH(pj, massN, atomicN, a, ntp)
+       use modXsecMedia
        implicit none
 #include  "Zcode.h"
 #include  "Zptcl.h"
@@ -404,8 +405,9 @@ c           make pi+ or -
           call cmkptc(kpion, 0, 0, pix)  ! can accept pi0
           call cadjm(pix, pix)  ! adjust momenutm
           call cxsecQGS(pix, massN,   xs )  ! not for xs 
-!          TargetXs = xs  ??
           call chAcol(pix, massN, atomicN, a, ntp)
+       elseif( ActiveMdl == "epos") then
+          call chAcol(pj, massN, atomicN, a, ntp)
        elseif (ActiveMdl /= "ad-hoc" ) then
           if(u < 0.5 ) then
              pichg = -1
