@@ -84,8 +84,11 @@ c      for ibm
          newdir.r(1) = yn(4)
          newdir.r(2) = yn(5)
          newdir.r(3) = yn(6)
-         newmom(:) = yn(4:6)**    sqrt(
-     *        dot_product( aTrack.p.fm.p(1:3),aTrack.p.fm.p(1:3)) )
+!               oh my god next yn(4:6)* sqrt(. ) was
+!                              yn(4:6)** sqrt(...)   !!!
+!             but default UseRungeKutta = 0 did not come here
+         newmom(:) = yn(4:6)* 
+     *   sqrt(dot_product( aTrack.p.fm.p(1:3),aTrack.p.fm.p(1:3)))
          newdir.sys='xyz'
       endif
       end
