@@ -185,8 +185,6 @@ c      --------------------------------------------------------------
 c
        real*8 dt, dispx, dispy
        logical nodef
-
-
        if(Reverse .eq. 0) then
           nodef = OneDim .ne. 0  .or.
      *    (mod(HowGeomag, 10) .eq. 1 .and. Zfirst.pos.depth .eq. 0.)
@@ -200,6 +198,7 @@ c         system is xyz;  if Efield exists, together with it
           call cmagDef
        endif
        if(.not. nodef .and. Reverse .eq. 0) then
+!                this is for multiple scattering
           call celecDef(dispx, dispy)  ! effect alrady put in
                     ! MovedTrack. dispx, y are dummy
        endif
@@ -245,23 +244,55 @@ ccc    *   ,norm
        logical usemiddle, high, usecmiddle
        real*8 cheight
        data cheight/30.d3/  
-       real*8 newmom(3)
+       real*8 newmom(3), dE, E1, E2, p1sq, p2sq, newE, norm
        save cheight
 
        leng = IntInfArray(ProcessNo).length
        if( HowEfield >= 1 ) then
           call cdefByMagAndE(TrackBefMove,  leng,  dispmr, dispmd,
      *     newmom)
+          p1sq =dot_product(TrackBefMove.p.fm.p(1:3),
+     *           TrackBefMove.p.fm.p(1:3))
+          E1 = sqrt( p1sq + TrackBefMove.p.mass**2)
+          p2sq =dot_product(newmom(1:3),newmom(1:3))
+          E2=sqrt(p2sq +  TrackBefMove.p.mass**2)
+          dE=E2-E1  !  may be + or -  depending on Ef and charge
+          ! dE/dx loss has been put in MovedTrack. adjust it again
+          
+          newE = MovedTrack.p.fm.p(4) + dE
+          if( newE <  TrackBefMove.p.mass ) then
+             newE =  TrackBefMove.p.mass
+             newmom(:) = 0
+          else
+             ! keeping the direction,adjust new momentum to be
+             ! consistent with newE
+             if( p2sq <= 0. ) then
+                write(0,*) ' p2sq = ',p2sq
+                write(0,*)
+     *          ' TrackBefMove.p=',TrackBefMove.p.fm.p(1:4)
+                write(0,*) ' dE, newE=',dE, newE
+                write(0,*) ' leng =', leng
+                write(0,*) 'dispmr=',dispmr.r(:)
+                write(0,*) 'dispmd=',dispmd.r(:)
+                write(0,*)
+     *            'code, chg=',TrackBefMove.p.code,
+     *            TrackBefMove.p.charge
+
+                newE = TrackBefMove.p.mass
+                newmom(:) = 0
+                dispmd.r(:) = (/0.,0.,1./)
+             else
+                norm = sqrt( (newE**2 - TrackBefMove.p.mass**2)/p2sq)
+                newmom(:) = newmom(:) *norm
+             endif
+          endif
+          MovedTrack.p.fm.p(4) = newE
 !          note. dispmr is r(new)-r(old) vector and different
 !          from other routines below. 
 !           dispmd is new dir and set at 100
           MovedTrack.pos.xyz.r(:) =  TrackBefMove.pos.xyz.r(:) +
      *         dispmr.r(:) 
           MovedTrack.p.fm.p(1:3) = newmom(:)
-           ! reset energy
-          MovedTrack.p.fm.p(4) =
-     *     sqrt( sum(  MovedTrack.p.fm.p(1:3)**2 ) + 
-     *                 MovedTrack.p.mass**2)
           goto 100
        endif
 c
@@ -411,7 +442,7 @@ c           if  dB/B~ dB^2/B^2/2 > 0.45 %, use RungeKutta.
              Mag = tempmag
           endif
        endif
-
+!!!!!!   default comes here
        if(UseRungeKutta .le. 5 .or. .not. high ) then
           call cmagneticDef(TrackBefMove, Mag, leng,
      *     dispmr, dispmd)
