@@ -5,10 +5,6 @@
                         !  Ze vB  ==> in GeV/c/s
       real(8),save:: ptclmass     ! mc^2 in GeV
       real(8),save:: ptclZ        ! charge
-!///////////
-!      integer,save::repeat=0
-!/////////////
-
       end       module modBEfield
 #include "Zcondc.h"
       subroutine cgetEfield(aTrack)
@@ -24,12 +20,12 @@
       if(HowEfield == 1 ) then
          call cEfield0(aTrack, Efld)
       else
-#if defined (EFIELD) 
+#if defined (MYEFIELD) 
 !        not simple Efield; user must define next
          call cmyEfield(aTrack, Efld)
 #else
          write(0,*) "HowEfield=",HowEfield," invalid"
-         write(0,*) "You must define EFIELD  in Zcondc.h"
+         write(0,*) "You must define MYEFIELD  in Zcondc.h"
          write(0,*)
      *    "and prepare cmyEfield subroutine in your apps."
      *    "Interface is cmyEfield(aTrack,Efout); see"
@@ -96,16 +92,12 @@
 !      write(*,'(a,1p, 3g14.4)') 'pos ', pos(:)
 !      write(*,'(a,1p, 3g14.4)') 'pos2 ',u(1:3,nstep)
 !!!!!!!!!!!!!!!
-      dispmd.r(:) = u(4:6,nstep)/
-     * sqrt( dot_product( u(4:6,nstep), u(4:6,nstep) ))
-!//////////
-!      if(repeat < 10 ) then
-!         write(0,*) ' p=u(4:6,0) = ', u(4:6,0)
-!         write(0,*) ' dt=',dt, ' gamma,beta=',gamma, bt
-!         write(0,*) ' dispmr.r(:)=',dispmr.r(:)
-!         write(0,*) ' new dir=',dispmd.r(:)
-!      endif
-!////////////
+      p2 =dot_product( u(4:6,nstep), u(4:6,nstep) )
+      if( p2 > 0.) then
+         dispmd.r(:) = u(4:6,nstep)/ sqrt( p2) 
+      else
+         dispmd.r(:) = (/0.,0.,1./)
+      endif
       newmom(:) = u(4:6,nstep)
       end    subroutine cdefByMagAndE
       
@@ -123,34 +115,17 @@
       real(8)::ans(nv)  !  f
 !               f(1:3) = dr/dt = beta c = pc/E
 !               f(4;6) = dp/dt = Ze(E+vxB) 
-
       real(8)::p2, E
       real(8)::vp(3), temp(3)
-
       vp(:) = u(4:6)  ! p
       p2= dot_product( vp, vp)
       E = sqrt(ptclmass**2 + p2)
 !      gamma = E/m
 !      beta = sqrt( (gamma-1)*(gamma+1))/gamma
       ans(1:3) = vp(:)*c/E  ! pc/E = c*beta => v
-      call kvec_prod3(ans(1:3), Bfld, ans(4:6))  ! vxB
-!//////////
-!      if(repeat< 10) then
-!         write(0,*) ' \vec V=',ans(1:3)
-!         write(0,*) ' VxB=',ans(4:6)
-!      endif
-!///////////
-      temp(1:3) =ptclZ*eval*(ans(4:6) + Efld(1:3))
-      ans(4:6) = temp(1:3)
-!/////////
-!      if(repeat< 10) then
-!         write(0,*) ' Efld=',Efld(:)
-!         write(0,*) ' Bfld=',Bfld(:)
-!         write(0,*) ' vec beta=',vp(:)/E,
-!     *    ' v=', sqrt(dot_product(ans(1:3), ans(1:3)))
-!         write(0,*) ' Ze(E+VxB)=',ans(4:6)
-!      endif
-!//////////////
+      call kvec_prod3(ans(1:3), Bfld, temp(1:3))  ! vxB
+      ans(4:6) = ptclZ*eval*(temp(1:3) + Efld(1:3))
+
       end function fBEdeflection
 
 
