@@ -71,9 +71,9 @@ c
      *                 oTrack.pos.xyz, oTrack.pos.xyz)
             call cxyz2primD(oTrack.vec.w, oTrack.vec.w)
 c///////////
-            write(0,*) ' bef chookobs'
-            write(0,*) 'xyz=', oTrack.pos.xyz
-            write(0,*) 's=', oTrack.vec.w
+c            write(0,*) ' bef chookobs'
+c            write(0,*) 'xyz=', oTrack.pos.xyz
+c            write(0,*) 's=', oTrack.vec.w
 c////////////
          endif
 c          call user routine      
