@@ -70,18 +70,18 @@ c     0 (within the computational accuracy).
 c
       if(id .eq. 2) then
 c            output typical quantities.
-        write(*, *) 
+        write(*, '(3i3, 1p, 4g15.4,0p, 4f10.6)')
      *  aTrack.where,   !  observation level. integer*2.  1 is highest.
      *  aTrack.p.code,    !  ptcl code.  integer*2.
      *  aTrack.p.charge,  !  charge,  integer*2 
-     *  sngl(aTrack.t), !  relateive arrival time in nsec (NOT sec).
+     *  aTrack.t, !  relateive arrival time in nsec (NOT sec).
                         !  if TimeStructure is F, nonsense.
-     *  sngl(aTrack.p.fm.p(4)),  ! total energy in GeV.
-     *  sngl(aTrack.pos.xyz.r(1)), sngl(aTrack.pos.xyz.r(2)), !  x, y in m
-     *  sngl(aTrack.vec.w.r(1)),  ! direc. cos.x in the current detector system.
-     *  sngl(aTrack.vec.w.r(2)),  ! direc. cos.y
-     *  sngl(aTrack.vec.w.r(3)),  ! direc. cos.z
-     *  sngl(aTrack.vec.coszenith) ! cos of zenith angle
+     *  aTrack.p.fm.p(4),  ! total energy in GeV.
+     *  aTrack.pos.xyz.r(1), aTrack.pos.xyz.r(2), !  x, y in m
+     *  aTrack.vec.w.r(1),  ! direc. cos.x in the current detector system.
+     *  aTrack.vec.w.r(2),  ! direc. cos.y
+     *  aTrack.vec.w.r(3),  ! direc. cos.z
+     *  aTrack.vec.coszenith ! cos of zenith angle
       endif
 c         you may need in some case other information such as
 c       aTrack.p.subcode   ! sub code of the particle integer*2
@@ -149,6 +149,8 @@ c     *
      *     ' in '//tracefile
          write(*, *)
      * ' ?=1,2..you can see it by Geomview or  gnuplot: '
+         write(*,*)
+     *    "It's a heavy task: choose small size data" 
          write(*, *)
      * 'Geomview gives nicer view; goto Util/Geomvie and invoke'
          write(*, *)
@@ -165,6 +167,9 @@ c     *
          write(*, *)  '           NF == 0 ;',qm, ' \ '
          write(*, *)  '         ',tracefile(1:klena(tracefile)),
      *        ' " w l '
+         write(*,*)
+         write(*,*)
+     * "Don't forget to make Trace=0 in 'param file' for normal jobs"  
 #ifdef sun4
          write(*, *) ' The last 3 lines should be on 1 line or',
      *        ' you need contination backslash'
