@@ -5,8 +5,9 @@ c           Some of them should be given mandatory.
      +  ASDepthList, ASHeightList, Azimuth, BaseTime, Cont, ContFile
      +, CosZenith, CutOffFile, Ddelta, DeadLine, DepthList, DestEventNo
      +, DtGMT, Freec, Generate, HeightList, HeightOfInj, Hidden
-     +, IncMuonPolari, InitRN, IntModel, Job, KEminObs, LatitOfSite
+     +, IncMuonPolari, InitRN, IntModel 
+     +, Job, KEminObs, LatitOfSite
      +, LongitOfSite, LpmEffect, MinPhotoProdE, ObsPlane, OneDim
      +, PhotoProd, PrimaryFile, SeedFile, SkeletonFile, SourceDec
      +, ThinSampling, TimeStructure, Trace, TraceDir, WaitRatio, Within
-     +, YearOfGeomag, Za1ry
+     +,XsecModel,  YearOfGeomag, Za1ry
