@@ -220,6 +220,17 @@ c	(->	--------------------------------------------
       integer MuBr            !2  parameter similar to MuNI but for bremsstrahlung by muons.
        integer MuPr           !2  parameter similar to MuNI but for pair creation by muons.
 
+       character(len=2):: ASRforDPM  !  D='m'
+               ! "no"  ; don't try to restore Pt asymmetry (
+               !         original dpm. some asymmetry for heavy
+               !         remnant side.
+               ! "r"   ; randomize Pt of mesons for Pz< 2GeV
+               !         in target rest frame and proj. rest frame
+               ! "r1"  ; do the same only for target rest frame
+               ! "m"   ; x <= -x  sign change with prob. of 1/2
+               !          for all particles. 
+               !However, If proj = p,pi.. and Target A<6, no ASR
+               !         If proj A<6 and target A<6, also no ASR
 c	 <-)	----------------------------------------------
 
 	common /cZtracp/ Truncc, Truncn, Truncx, 
@@ -235,7 +246,8 @@ c	 <-)	----------------------------------------------
      *  EndLevel, EndLevel2, Eabsorb, HowPhotoP, PhitsXS,
      *  JamXs, AAXsec, JamFragment
  
-        common /cZtrackpc/ Generate, Generate2, TraceDir
+        common /cZtrackpc/
+     *  Generate, Generate2, TraceDir, ASRforDPM
  
 
 
